/* Copyright 2026 Oliver Smith, Peter Mack
 * SPDX-License-Identifier: MPL-2.0 */

@media (max-width: 700px) {
    .findbar-container {
        display: flex;
        flex-direction: row;
        flex-wrap: wrap;
        height: 30px !important;
    }
    .findbar-textbox {
        width: 100% !important;
    }
    .findbar-highlight,
    .findbar-case-sensitive,
    .findbar-entire-word,
    .findbar-find-status,
    .findbar-label.found-matches,
    .findbar-match-diacritics {
        display: none !important;
    }
}
